@@ -11,7 +11,7 @@ class TableManager:
     def __init__(self, connector: MySQLConnector):
         self.connector = connector
 
-    def create_table(self, create_table_request: CreateTableRequest) -> None:
+    def create_table(self, create_table_request: CreateTableRequest) -> dict:
         if create_table_request.data is not None:
             return create_table_from_data_util(create_table_request, self.connector, create_table_request.data)
         else:
