@@ -19,7 +19,8 @@ class CreateTableRequest(BaseModel):
     name: str
     fields: Optional[List[NewTableField]] = None
     data: Optional[str] = None
-    if_exists: IfExists = IfExists.SKIP
+    primary_key_field: Optional[str] = None
+    if_exists: IfExists = IfExists.ERROR
     autoconnect: bool = False
 
 class DropTableRequest(BaseModel):
